Learn R Programming

gamboostLSS (version 1.2-0)

india: Malnutrition of Children in India (DHS, 1998-99)

Description

Data sample from the Standard Demographic and Health Survey, 1998-99, on malnutrition of children in India. The data set contains approximately 12% of the observations in the original data set and only a (very small) subset of variables. Additionally, a boundary file representing the districts of India is provided for spatial analysis.

Usage

data(india)
data(india.bnd)

Arguments

source

The complete data set is provided by the Monitoring and Evaluation to Assess and Use Results Demographic and Health Surveys (MEASURE DHS) which is funded by the U.S. Agency of International Development (USAID). It can be obtained for research purposes (after registration) from http://www.measuredhs.com/what-we-do/survey/survey-display-156.cfm (Data set for All-India, Children's Recode: iakr42dt.zip)

Details

For details on the boundary file see function read.bnd from package BayesX.

References

For details on the data set see also:

Fahrmeir L and Kneib T (2011), Bayesian smoothing and regression for longitudinal, spatial and event history data, Oxford University Press.

Examples

Run this code
if (require("BayesX")) {
  ## plot distribution of stunting in India
  drawmap(india, map = india.bnd, regionvar = "mcdist", plotvar = "stunting")
}

Run the code above in your browser using DataLab